@@ -1,10 +1,11 @@
 package Object::eBay::Item;
-our $VERSION = '0.0.3';
+our $VERSION = '0.1.0';
 
 use Class::Std; {
     use warnings;
     use strict;
     use base qw( Object::eBay );
+    use overload '""' => 'item_id', fallback => 1;
 
     sub api_call       { "GetItem" };
     sub response_field { "Item"    };
@@ -36,6 +37,18 @@ use Class::Std; {
         },
     });
 
+    sub item_id  { shift->api_inputs->{ItemID} }
+
+    sub is_ended {
+        my ($self) = @_;
+        my $status = $self->selling_status->listing_status;
+        die "eBay item #$self has no listing status\n" if not defined $status;
+
+        return   if $status eq 'Active';
+        return 1 if $status eq 'Ended';
+        return 1 if $status eq 'Completed';
+        die "eBay item #$self has an unknown listing status: $status\n";
+    }
 
     #########################################################################
     # Usage     : my @images = $item->pictures()
@@ -83,15 +96,9 @@ use Class::Std; {
 __END__
 
 =head1 NAME
- 
+
 Object::eBay::Item - Represents an item listed on eBay
- 
- 
-=head1 VERSION
- 
-This documentation refers to Object::eBay::Item version 0.0.3
- 
- 
+
 =head1 SYNOPSIS
 
     # assuming that Object::eBay has already been initialized
@@ -109,7 +116,7 @@ on eBay.
 
 =head2 new
 
-A single 'item_id' argument is required.  The valu of the argument should be
+A single 'item_id' argument is required.  The value of the argument should be
 the eBay item ID of the item you want to represent.
 
 =head2 buy_it_now_price
@@ -131,6 +138,17 @@ method on an Object::eBay::Item object, please specify 'description' in the
 C<needs_methods> list when creating the object (see L</new>).  If you don't
 specify C<needs_methods> correctly, this method will not be available.
 
+=head2 is_ended
+
+Returns true if the eBay auction for this item has ended.  Otherwise, it
+returns false.
+
+=head2 item_id
+
+Returns the eBay item ID for this auction.  This is the same as the
+"item_id" argument to L</new>.  This method also provides the value
+when an Item object is used in string context.
+
 =head2 listing_details
 
 Returns a L<Object::eBay::ListingDetails> object.
